==> mingw-w64-i686-kcompletion-qt5-5.75.0-1-any.pkg.tar.zst: mingw32/include/KF5/KCompletion/kcompletion_export.h <==

#ifndef KCOMPLETION_EXPORT_H
#define KCOMPLETION_EXPORT_H

#ifdef KCOMPLETION_STATIC_DEFINE
#  define KCOMPLETION_EXPORT
#  define KCOMPLETION_NO_EXPORT
#else
#  ifndef KCOMPLETION_EXPORT
#    ifdef KF5Completion_EXPORTS
        /* We are building this library */
#      define KCOMPLETION_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KCOMPLETION_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KCOMPLETION_NO_EXPORT
#    define KCOMPLETION_NO_EXPORT 
#  endif
#endif

#ifndef KCOMPLETION_DECL_DEPRECATED
#  define KCOMPLETION_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCOMPLETION_DECL_DEPRECATED_EXPORT
#  define KCOMPLETION_DECL_DEPRECATED_EXPORT KCOMPLETION_EXPORT KCOMPLETION_DECL_DEPRECATED
#endif

#ifndef KCOMPLETION_DECL_DEPRECATED_NO_EXPORT
#  define KCOMPLETION_DECL_DEPRECATED_NO_EXPORT KCOMPLETION_NO_EXPORT KCOMPLETION_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCOMPLETION_NO_DEPRECATED
#    define KCOMPLETION_NO_DEPRECATED
#  endif
#endif

#define KCOMPLETION_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCOMPLETION_NO_DEPRECATED) && !defined(KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCOMPLETION_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCOMPLETION_NO_DEPRECATED_WARNINGS) && !defined(KCOMPLETION_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCOMPLETION_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCOMPLETION_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCOMPLETION_NO_DEPRECATED)
#  undef KCOMPLETION_DEPRECATED
#  define KCOMPLETION_DEPRECATED_EXPORT KCOMPLETION_EXPORT
#  define KCOMPLETION_DEPRECATED_NO_EXPORT KCOMPLETION_NO_EXPORT
#elif defined(KCOMPLETION_NO_DEPRECATED_WARNINGS)
#  define KCOMPLETION_DEPRECATED
#  define KCOMPLETION_DEPRECATED_EXPORT KCOMPLETION_EXPORT
#  define KCOMPLETION_DEPRECATED_NO_EXPORT KCOMPLETION_NO_EXPORT
#else
#  define KCOMPLETION_DEPRECATED KCOMPLETION_DECL_DEPRECATED
#  define KCOMPLETION_DEPRECATED_EXPORT KCOMPLETION_DECL_DEPRECATED_EXPORT
#  define KCOMPLETION_DEPRECATED_NO_EXPORT KCOMPLETION_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCOMPLETION_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCOMPLETION_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCOMPLETION_NO_DEPRECATED
#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54b00
#endif
#ifdef KCOMPLETION_NO_DEPRECATED_WARNINGS
#  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCOMPLETION_DEPRECATED_WARNINGS_SINCE
#  ifdef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x54b00
#  endif
#endif

#ifndef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCOMPLETION_DEPRECATED
#  define KCOMPLETION_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCOMPLETION_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KCOMPLETION_DEPRECATED_VERSION_4_0(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_4_0(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x40500
#  define KCOMPLETION_DEPRECATED_VERSION_4_5(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_4_5(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KCOMPLETION_DEPRECATED_VERSION_5_0(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_0(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x52e00
#  define KCOMPLETION_DEPRECATED_VERSION_5_46(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_46(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x54200
#  define KCOMPLETION_DEPRECATED_VERSION_5_66(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_66(text)
#endif
#define KCOMPLETION_DEPRECATED_VERSION_4(minor, text)      KCOMPLETION_DEPRECATED_VERSION_4_##minor(text)
#define KCOMPLETION_DEPRECATED_VERSION_5(minor, text)      KCOMPLETION_DEPRECATED_VERSION_5_##minor(text)
#define KCOMPLETION_DEPRECATED_VERSION(major, minor, text) KCOMPLETION_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KCOMPLETION_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOMPLETION_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)

#endif /* KCOMPLETION_EXPORT_H */

==> mingw-w64-i686-kcompletion-qt5-5.100.0-2-any.pkg.tar.zst: mingw32/include/KF5/KCompletion/kcompletion_export.h <==

#ifndef KCOMPLETION_EXPORT_H
#define KCOMPLETION_EXPORT_H

#ifdef KCOMPLETION_STATIC_DEFINE
#  define KCOMPLETION_EXPORT
#  define KCOMPLETION_NO_EXPORT
#else
#  ifndef KCOMPLETION_EXPORT
#    ifdef KF5Completion_EXPORTS
        /* We are building this library */
#      define KCOMPLETION_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KCOMPLETION_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KCOMPLETION_NO_EXPORT
#    define KCOMPLETION_NO_EXPORT 
#  endif
#endif

#ifndef KCOMPLETION_DECL_DEPRECATED
#  define KCOMPLETION_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCOMPLETION_DECL_DEPRECATED_EXPORT
#  define KCOMPLETION_DECL_DEPRECATED_EXPORT KCOMPLETION_EXPORT KCOMPLETION_DECL_DEPRECATED
#endif

#ifndef KCOMPLETION_DECL_DEPRECATED_NO_EXPORT
#  define KCOMPLETION_DECL_DEPRECATED_NO_EXPORT KCOMPLETION_NO_EXPORT KCOMPLETION_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCOMPLETION_NO_DEPRECATED
#    define KCOMPLETION_NO_DEPRECATED
#  endif
#endif

#define KCOMPLETION_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCOMPLETION_NO_DEPRECATED) && !defined(KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCOMPLETION_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCOMPLETION_NO_DEPRECATED_WARNINGS) && !defined(KCOMPLETION_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCOMPLETION_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCOMPLETION_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCOMPLETION_NO_DEPRECATED)
#  undef KCOMPLETION_DEPRECATED
#  define KCOMPLETION_DEPRECATED_EXPORT KCOMPLETION_EXPORT
#  define KCOMPLETION_DEPRECATED_NO_EXPORT KCOMPLETION_NO_EXPORT
#elif defined(KCOMPLETION_NO_DEPRECATED_WARNINGS)
#  define KCOMPLETION_DEPRECATED
#  define KCOMPLETION_DEPRECATED_EXPORT KCOMPLETION_EXPORT
#  define KCOMPLETION_DEPRECATED_NO_EXPORT KCOMPLETION_NO_EXPORT
#else
#  define KCOMPLETION_DEPRECATED KCOMPLETION_DECL_DEPRECATED
#  define KCOMPLETION_DEPRECATED_EXPORT KCOMPLETION_DECL_DEPRECATED_EXPORT
#  define KCOMPLETION_DEPRECATED_NO_EXPORT KCOMPLETION_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCOMPLETION_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCOMPLETION_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCOMPLETION_NO_DEPRECATED
#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56400
#endif
#ifdef KCOMPLETION_NO_DEPRECATED_WARNINGS
#  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCOMPLETION_DEPRECATED_WARNINGS_SINCE
#  ifdef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x56400
#  endif
#endif

#ifndef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCOMPLETION_DEPRECATED
#  define KCOMPLETION_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCOMPLETION_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KCOMPLETION_DEPRECATED_VERSION_4_0(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_4_0(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x40500
#  define KCOMPLETION_DEPRECATED_VERSION_4_5(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_4_5(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KCOMPLETION_DEPRECATED_VERSION_5_0(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_0(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x52e00
#  define KCOMPLETION_DEPRECATED_VERSION_5_46(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_46(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x54200
#  define KCOMPLETION_DEPRECATED_VERSION_5_66(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_66(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x55100
#  define KCOMPLETION_DEPRECATED_VERSION_5_81(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_81(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x55300
#  define KCOMPLETION_DEPRECATED_VERSION_5_83(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_83(text)
#endif
#define KCOMPLETION_DEPRECATED_VERSION_4(minor, text)      KCOMPLETION_DEPRECATED_VERSION_4_##minor(text)
#define KCOMPLETION_DEPRECATED_VERSION_5(minor, text)      KCOMPLETION_DEPRECATED_VERSION_5_##minor(text)
#define KCOMPLETION_DEPRECATED_VERSION(major, minor, text) KCOMPLETION_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KCOMPLETION_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOMPLETION_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCOMPLETION_DEPRECATED_VERSION(major, minor, text)
#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOMPLETION_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KCOMPLETION_EXPORT_H */


#ifndef ECM_GENERATEEXPORTHEADER_KCOMPLETION_EXPORT_H
#define ECM_GENERATEEXPORTHEADER_KCOMPLETION_EXPORT_H


#define KCOMPLETION_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCOMPLETION_NO_DEPRECATED) && !defined(KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCOMPLETION_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCOMPLETION_NO_DEPRECATED_WARNINGS) && !defined(KCOMPLETION_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCOMPLETION_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCOMPLETION_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCOMPLETION_NO_DEPRECATED)
#  undef KCOMPLETION_DEPRECATED
#  define KCOMPLETION_DEPRECATED_EXPORT KCOMPLETION_EXPORT
#  define KCOMPLETION_DEPRECATED_NO_EXPORT KCOMPLETION_NO_EXPORT
#elif defined(KCOMPLETION_NO_DEPRECATED_WARNINGS)
#  define KCOMPLETION_DEPRECATED
#  define KCOMPLETION_DEPRECATED_EXPORT KCOMPLETION_EXPORT
#  define KCOMPLETION_DEPRECATED_NO_EXPORT KCOMPLETION_NO_EXPORT
#else
#  define KCOMPLETION_DEPRECATED KCOMPLETION_DECL_DEPRECATED
#  define KCOMPLETION_DEPRECATED_EXPORT KCOMPLETION_DECL_DEPRECATED_EXPORT
#  define KCOMPLETION_DEPRECATED_NO_EXPORT KCOMPLETION_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCOMPLETION_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCOMPLETION_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCOMPLETION_NO_DEPRECATED
#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56400
#endif
#ifdef KCOMPLETION_NO_DEPRECATED_WARNINGS
#  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCOMPLETION_DEPRECATED_WARNINGS_SINCE
#  ifdef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x56400
#  endif
#endif

#ifndef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCOMPLETION_DEPRECATED
#  define KCOMPLETION_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCOMPLETION_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KCOMPLETION_DEPRECATED_VERSION_4_0(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_4_0(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x40500
#  define KCOMPLETION_DEPRECATED_VERSION_4_5(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_4_5(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KCOMPLETION_DEPRECATED_VERSION_5_0(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_0(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x52e00
#  define KCOMPLETION_DEPRECATED_VERSION_5_46(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_46(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x54200
#  define KCOMPLETION_DEPRECATED_VERSION_5_66(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_66(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x55100
#  define KCOMPLETION_DEPRECATED_VERSION_5_81(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_81(text)
#endif

#if KCOMPLETION_DEPRECATED_WARNINGS_SINCE >= 0x55300
#  define KCOMPLETION_DEPRECATED_VERSION_5_83(text) KCOMPLETION_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOMPLETION_DEPRECATED_VERSION_5_83(text)
#endif
#define KCOMPLETION_DEPRECATED_VERSION_4(minor, text)      KCOMPLETION_DEPRECATED_VERSION_4_##minor(text)
#define KCOMPLETION_DEPRECATED_VERSION_5(minor, text)      KCOMPLETION_DEPRECATED_VERSION_5_##minor(text)
#define KCOMPLETION_DEPRECATED_VERSION(major, minor, text) KCOMPLETION_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KCOMPLETION_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOMPLETION_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCOMPLETION_DEPRECATED_VERSION(major, minor, text)
#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOMPLETION_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KCOMPLETION_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif


#endif /* ECM_GENERATEEXPORTHEADER_KCOMPLETION_EXPORT_H */
